@@ -1,5 +1,3 @@
-import os
-import stat
 import typing as ty
 import json
 import itertools
@@ -12,13 +10,10 @@ import shutil
 from dataclasses import dataclass
 import pytest
 import docker
+from fileformats.medimage import NiftiX
 from arcana.core import __version__
-from fileformats.medimage import NiftiX, NiftiGzX, NiftiGzXBvec
 from arcana.core.data.space import Clinical
 from arcana.bids.data import Bids
-from arcana.bids.tasks import bids_app, BidsInput, BidsOutput
-from fileformats.text import Plain as Text
-from fileformats.generic import Directory
 
 
 MOCK_BIDS_APP_NAME = "mockapp"
@@ -36,7 +31,7 @@ def test_bids_roundtrip(bids_validator_docker, bids_success_str, work_dir):
     member_ids = [str(i) for i in range(1, 4)]
     subject_ids = ["{}{}".format(*t) for t in itertools.product(group_ids, member_ids)]
     timepoint_ids = [str(i) for i in range(1, 3)]
-    dataset = Bids().new_dataset(
+    dataset = Bids().create_dataset(
         id=path,
         name=dataset_name,
         space=Clinical,
@@ -192,7 +187,7 @@ def test_bids_json_edit(json_edit_blueprint: JsonEditBlueprint, work_dir: Path):
     shutil.rmtree(path, ignore_errors=True)
     dataset = Bids(
         json_edits=[(bp.path_re, bp.jq_script)],
-    ).new_dataset(
+    ).create_dataset(
         id=path,
         name=name,
         leaves=[("1",)],
@@ -247,83 +242,3 @@ def test_bids_json_edit(json_edit_blueprint: JsonEditBlueprint, work_dir: Path):
             saved_dict = json.load(f)
 
         assert saved_dict == sf_bp.edited_side_car
-
-
-BIDS_INPUTS = [
-    BidsInput(name="T1w", path="anat/T1w", datatype=NiftiGzX),
-    BidsInput(name="T2w", path="anat/T2w", datatype=NiftiGzX),
-    BidsInput(name="dwi", path="dwi/dwi", datatype=NiftiGzXBvec),
-]
-BIDS_OUTPUTS = [
-    BidsOutput(name="whole_dir", datatype=Directory),  # whole derivative directory
-    BidsOutput(name="a_file", path="file1", datatype=Text),
-    BidsOutput(name="another_file", path="file2", datatype=Text),
-]
-
-
-def test_run_bids_app_docker(
-    bids_validator_app_image: str, nifti_sample_dir: Path, work_dir: Path
-):
-
-    kwargs = {}
-
-    bids_dir = work_dir / "bids"
-
-    shutil.rmtree(bids_dir, ignore_errors=True)
-
-    task = bids_app(
-        name=MOCK_BIDS_APP_NAME,
-        container_image=bids_validator_app_image,
-        executable="/launch.sh",  # Extracted using `docker_image_executable(docker_image)`
-        inputs=BIDS_INPUTS,
-        outputs=BIDS_OUTPUTS,
-        dataset=bids_dir,
-    )
-
-    for inpt in BIDS_INPUTS:
-        kwargs[inpt.name] = nifti_sample_dir.joinpath(
-            *inpt.path.split("/")
-        ).with_suffix(inpt.datatype.ext)
-
-    result = task(plugin="serial", **kwargs)
-
-    for output in BIDS_OUTPUTS:
-        assert Path(getattr(result.output, output.name)).exists()
-
-
-def test_run_bids_app_naked(
-    mock_bids_app_script: str, nifti_sample_dir: Path, work_dir: Path
-):
-
-    # Create executable that runs validator then produces some mock output
-    # files
-    launch_sh = work_dir / "launch.sh"
-    # We don't need to run the full validation in this case as it is already tested by test_run_bids_app_docker
-    # so we use the simpler test script.
-    with open(launch_sh, "w") as f:
-        f.write(mock_bids_app_script)
-
-    os.chmod(launch_sh, stat.S_IRWXU)
-
-    task = bids_app(
-        name=MOCK_BIDS_APP_NAME,
-        executable=launch_sh,  # Extracted using `docker_image_executable(docker_image)`
-        inputs=BIDS_INPUTS,
-        outputs=BIDS_OUTPUTS,
-        app_output_dir=work_dir / "output",
-    )
-
-    kwargs = {}
-    for inpt in BIDS_INPUTS:
-        kwargs[inpt.name] = nifti_sample_dir.joinpath(
-            *inpt.path.split("/")
-        ).with_suffix(inpt.datatype.ext)
-
-    bids_dir = work_dir / "bids"
-
-    shutil.rmtree(bids_dir, ignore_errors=True)
-
-    result = task(plugin="serial", **kwargs)
-
-    for output in BIDS_OUTPUTS:
-        assert Path(getattr(result.output, output.name)).exists()
